@@ -1,6 +1,6 @@
 import string
-__version__ = string.split('$Revision: 1.7 $')[1]
-__date__ = string.join(string.split('$Date: 2001/08/10 18:42:33 $')[1:3], ' ')
+__version__ = string.split('$Revision: 1.8 $')[1]
+__date__ = string.join(string.split('$Date: 2001/11/17 14:12:34 $')[1:3], ' ')
 __author__ = 'Tarn Weisner Burton <twburton@users.sourceforge.net>'
 __doc__ = 'http://oss.sgi.com/projects/ogl-sample/registry/EXT/texture_compression_s3tc.txt'
 __api_version__ = 0x007
@@ -13,7 +13,7 @@ GL_COMPRESSED_RGBA_S3TC_DXT5_EXT = 0x83F3
 
 def glInitTextureCompressionS3tcEXT():
 	from OpenGL.GL import __has_extension
-	return __has_extension("GL_EXT_texure_compression_s3tc")
+	return __has_extension("GL_EXT_texture_compression_s3tc")
 
 glInitTexCompressionS3tcEXT = glInitTextureCompressionS3tcEXT
 
