@@ -1,5 +1,7 @@
 /*
+# BUILD sources []
 # BUILD api_version_check 0
+# BUILD include_dirs []
 */
 #include "../config.h"
 
