@@ -1,9 +1,10 @@
 /*
-# BUILD libs ['GLUT']
+# BUILD sources []
 # BUILD api_version_check 0
+# BUILD libs ['GLUT']
+# BUILD include_dirs []
 */
 #include "../config.h"
-#include <GL/glut.h>
 
 #if GLUT_XLIB_IMPLEMENTATION >= 13
 #include "GLUT.000d.inc"
