@@ -1,7 +1,9 @@
 /*
-# BUILD libs ['gdi32']
-# BUILD api_version_check 0
 # BUILD gl_platforms ['WGL']
+# BUILD sources []
+# BUILD api_version_check 0
+# BUILD libs ['gdi32']
+# BUILD include_dirs []
 */
 #include "../config.h"
 
