@@ -99,15 +99,18 @@ PyObject* _PyObject_From##NAME(int nd, int* dims, BASE* data, int own)\
 	{\
 		BASE* my;\
 		int i, l;\
-\
-		if (own) my = data; else\
-		{\
-			for (i = 0, l = 1; i < nd; i++) l *= dims[i];\
-			my = PyMem_New(BASE, l);\
-			memcpy(my, data, sizeof(BASE)*l);\
+		PyObject * result;\
+		\
+		result = PyArray_FromDims(nd, dims, TYPECODE);\
+		/* get total length */\
+		for (i = 0, l = 1; i < nd; i++) {\
+			l *= dims[i];\
 		}\
-\
-		return PyArray_FromDimsAndData(nd, dims, TYPECODE, (char*)my);\
+		/* get a simple array of base-type to copy */\
+		my = (BASE *) ((PyArrayObject *) result)->data;\
+		/* copy the data */\
+		for (i=0;i<l;i++) { my[i] = data[i];}\
+		return result;\
 	}\
 	return NonNumeric_PyObject_From##NAME(nd, dims, data, own);\
 }
@@ -601,7 +604,7 @@ int __PyObject_As##NAME(BASE* dest, PyObject* src)\
 		{\
 			item = PySequence_GetItem(src, i);\
 			if (!item) return 0;\
-			l += p = __PyObject_As##NAME(dest + l, item);\
+			l += (p = __PyObject_As##NAME(dest + l, item));\
 			Py_DECREF(item);\
 			if (!p) return 0;\
 		}\
@@ -655,22 +658,27 @@ BASE* Numeric_PyObject_As##NAME(PyObject *source, PyObject **temp, int *len)\
 {\
 	int size;\
 	BASE* target = NULL;\
-	PyArrayObject *contiguous;\
-\
-	size = PyArray_Size(source);\
-	if (len) *len = size;\
+	PyArrayObject *contiguous = NULL;\
+	/*printf( "Getting contiguous\n");*/\
+	/* yes, this is redundant, as we are borrowing caller's pointer, I'm paranoid */\
+	Py_INCREF( source );\
 	contiguous = (PyArrayObject*)PyArray_ContiguousFromObject(source, TYPECODE | SAVESPACEBIT, 0, 0);\
 	if (contiguous)\
 	{\
-		if (temp)\
-		{\
+		/* only need to calculate this if we actually got the contiguous array */\
+		size = PyArray_Size(contiguous);\
+		/*printf( "Got array size %i\n", size );*/\
+		if (len) { *len = size;}\
+		if (temp) {\
+			/*printf( "Pointing passed temp pointer to contiguous data pointer\n" );*/\
 			*temp = (PyObject*)contiguous;\
 			target = (BASE*)contiguous->data;\
-		}\
-		else\
-		{\
+		} else {\
+			/*printf( "Creating new target array\n");*/\
 			target = PyMem_New(BASE, size);\
+			/*printf( "Copying old data to new\n");*/\
 			memcpy(target, contiguous->data, sizeof(BASE)*size);\
+			/*printf( "Decrefing contiguous data array...\n");*/\
 			Py_DECREF((PyObject*)contiguous);\
 		}\
 	}\
@@ -678,12 +686,13 @@ BASE* Numeric_PyObject_As##NAME(PyObject *source, PyObject **temp, int *len)\
 	{\
 		PyErr_SetString(PyExc_ValueError, "Unable to get contiguous array from object");\
 	}\
+	Py_DECREF( source );\
 	return target;\
 }\
 BASE* _PyObject_As##NAME(PyObject *source, PyObject **temp, int *len)\
 {\
-	if (temp) *temp = NULL;\
-	if (source == Py_None) return NULL;\
+	if (temp) { *temp = NULL;}\
+	if (source == Py_None) {return NULL;}\
 	if (PyArray_API && PyArray_Check(source)) return Numeric_PyObject_As##NAME(source, temp, len);\
 	return NonNumeric_PyObject_As##NAME(source, temp, len);\
 }
